**Example 1: 更新设备日志级别**



Input: 

```
tccli iotcloud UpdateDeviceLogLevel --cli-unfold-argument  \
    --ProductId ABCDE12345 \
    --DeviceName abc \
    --LogLevel 1
```

Output: 
```
{
    "Response": {
        "RequestId": "9e574269-093f-4a7f-bf90-24ef80b6528a"
    }
}
```

